;;; DO NOT MODIFY THIS FILE
(if (featurep 'ilisp-autoloads) (error "Already loaded"))

(provide 'ilisp-autoloads)

;;;### (autoloads nil "_pkg" "ilisp/_pkg.el")

(package-provide 'ilisp :version 1.09 :type 'regular)

;;;***
